# I'm so sorry

Sometimes it can be necessary to call upon the ancient arts...

A module to uwuify strings of text.

## Installation

You can install `imsosorry` through PyPi using
```sh
$ pip install imsosorry
```

or, by installing the development version through GitHub.
```sh
$ pip install git+https://github.com/letsbuilda/imsosorry
```

### Example usage

```py
import imsosorry

print(imsosorry.uwuify("i'm very sorry"))
```
